@@ -58,7 +58,8 @@ def _decode_environment():
 @click.option('--debug', 'debug', is_flag=True, help='Show debug output', default=False)
 @click.option('--colorize', 'colorize', is_flag=True, help='Color output', default=False)
 @click.option('--version-check/--no-version-check', is_flag=True, help='Check for new version on PyPI', default=True)
-def cli(ctx=None, see_version=None, debug=False, colorize=False, version_check=True):
+@click.option('--interpreter', '-i', required=False, default=None, help='Select a specific interpreter / user interface', hidden=True)
+def cli(ctx=None, see_version=None, debug=False, colorize=False, version_check=True, interpreter=None):
     """
         Lager CLI
     """
@@ -76,7 +77,7 @@ def cli(ctx=None, see_version=None, debug=False, colorize=False, version_check=T
         skip_auth = ctx.invoked_subcommand in ('login', 'logout', 'set', 'devenv', 'exec') or help_invoked
         if version_check and not skip_auth:
             check_version('lager-cli', __version__)
-        setup_context(ctx, debug, colorize, skip_auth)
+        setup_context(ctx, debug, colorize, skip_auth, interpreter)
 
 cli.add_command(_gateway)
 cli.add_command(adc)
@@ -112,7 +113,7 @@ cli.add_command(spi)
 cli.add_command(i2c)
 cli.add_command(pip)
 
-def setup_context(ctx, debug, colorize, skip_auth):
+def setup_context(ctx, debug, colorize, skip_auth, interpreter):
     """
         Ensure the user has a valid authorization
     """
@@ -138,4 +139,5 @@ def setup_context(ctx, debug, colorize, skip_auth):
         defaults=config['LAGER'],
         debug=debug,
         style=click.style if colorize else lambda string, **kwargs: string,
+        interpreter=interpreter,
     )
