@@ -316,16 +316,15 @@ class LagerSession(BaseUrlSession):
         }
         return self.post(url, json=json_data)
 
-    def remote_debug(self, gateway, archive, elf_file, interpreter):
+    def remote_debug(self, gateway, archive, args):
         """
             Start a remote debugging session
         """
         url = 'gateway/{}/remote-debug'.format(quote(gateway))
 
         files = [
-            ('elf_file', elf_file),
             ('archive', archive),
-            ('interpreter', interpreter),
+            ('args', json.dumps(args)),
         ]
         return self.post(url, files=files)
 
@@ -517,7 +516,7 @@ class LagerContext:  # pylint: disable=too-few-public-methods
     """
         Lager Context manager
     """
-    def __init__(self, ctx, auth, defaults, debug, style):
+    def __init__(self, ctx, auth, defaults, debug, style, interpreter=None):
         ws_host = os.getenv('LAGER_WS_HOST', _DEFAULT_WEBSOCKET_HOST)
         response_hook = functools.partial(LagerSession.handle_errors, ctx)
         self.session = LagerSession(auth, response_hook=response_hook)
@@ -526,6 +525,7 @@ class LagerContext:  # pylint: disable=too-few-public-methods
         self.style = style
         self.ws_host = ws_host
         self.debug = debug
+        self.interpreter = interpreter
         if auth:
             self.auth_token = auth['token']
 
