@@ -164,6 +164,12 @@ CanFilter = collections.namedtuple('CanFilter', [
     'extended',
 ])
 
+PortForwardSpecifier = collections.namedtuple('PortForwardSpecifier', [
+    'src',
+    'dst',
+    'proto',
+])
+
 def parse_can_data(data_str):
     parts = data_str.split('.')
     return list(b''.join([bytes.fromhex(part) for part in parts]))
@@ -306,3 +312,39 @@ class CanbusRange(click.ParamType):
 
     def __repr__(self):
         return 'CAN_RANGE'
+
+
+class PortForwardType(click.ParamType):
+    """
+        Environment variable
+    """
+    name = 'PORT'
+    regex = re.compile(r'\A([0-9]+)(:[0-9]+)?(/[a-z]+)?\Z')
+    RESERVED = [2331, 3333, 4444, 8081, 5555, 8888]
+
+    def convert(self, value, param, ctx):
+        """
+            Parse string representation of environment variable
+        """
+        match = self.regex.search(value)
+        if not match:
+            self.fail(f'Invalid port specifier "{value}".', param, ctx)
+
+        source = int(match[1], 10)
+        if source in self.RESERVED:
+            self.fail(f'Port {source} is reserved for internal use on the gateway.', param, ctx)
+
+        if match[2]:
+            dest = int(match[2][1:], 10)
+        else:
+            dest = source
+
+        if match[3]:
+            protocol = match[3][1:]
+        else:
+            protocol = None
+
+        return PortForwardSpecifier(source, dest, protocol)
+
+    def __repr__(self):
+        return 'PORT FORWARD'
