@@ -7,6 +7,7 @@ import os
 import shutil
 import gzip
 import json
+import uuid
 import sys
 import threading
 import pathlib
@@ -136,7 +137,7 @@ def python(ctx, runnable, gateway, image, env, passenv, kill, download, allow_ov
 
     if kill:
         signum = _get_signal_number(signum)
-        resp = session.kill_python(gateway, signum)
+        resp = session.kill_python(gateway, None, signum)
         resp.raise_for_status()
         return
 
@@ -154,6 +155,8 @@ def python(ctx, runnable, gateway, image, env, passenv, kill, download, allow_ov
     post_data.extend(
         zip(itertools.repeat('env'), env)
     )
+    lager_process_id = str(uuid.uuid4())
+    post_data.append(('env', f'LAGER_PROCESS_ID={lager_process_id}'))
     post_data.extend(
         zip(itertools.repeat('env'), [f'{name}={os.environ[name]}' for name in passenv])
     )
@@ -181,7 +184,7 @@ def python(ctx, runnable, gateway, image, env, passenv, kill, download, allow_ov
         post_data.append(('module', zipped_folder))
 
     resp = session.run_python(gateway, files=post_data)
-    kill_python = functools.partial(session.kill_python, gateway)
+    kill_python = functools.partial(session.kill_python, gateway, lager_process_id)
     handler = functools.partial(sigint_handler, kill_python)
     signal.signal(signal.SIGINT, handler)
 
