@@ -52,6 +52,7 @@ def access_points(ctx, gateway, interface=None):
     session = ctx.obj.session
     resp = session.get_wifi_access_points(gateway, interface)
     resp.raise_for_status()
+    seen = set()
 
     table = Texttable()
     table.set_deco(Texttable.HEADER)
@@ -59,7 +60,9 @@ def access_points(ctx, gateway, interface=None):
     table.set_cols_align(['l', 'l', 'r'])
     table.header(['ssid', 'security', 'strength'])
     for ap in resp.json().get('access_points', []):
-        table.add_row([ap['ssid'], ap['security'], ap['strength']])
+        if ap['ssid'] not in seen:
+            table.add_row([ap['ssid'], ap['security'], ap['strength']])
+        seen.add(ap['ssid'])
 
     click.echo(table.draw())
 
